@@ -28,6 +28,7 @@ class Recipe(object):
             raise zc.buildout.UserError('Configuration error')
 
         self.gems = options['gems'].split()
+        self.version = options.get('version')
 
 
     def run(self, cmd, environ=None):
@@ -78,6 +79,10 @@ class Recipe(object):
         }
 
     def _get_latest_rubygems(self):
+        if self.version:
+            return ('http://production.cf.rubygems.org/rubygems/'
+                    'rubygems-%s.zip' % self.version, self.version)
+
         f = urllib.urlopen('http://rubygems.org/pages/download')
         s = f.read()
         f.close()
